caellion-python-commons: parse-tests Namespace Reference

caellion-python-commons

Variables
parse-tests Namespace Reference

## Variables
| tree = ET.parse("reports/nose2-junit.xml")
| root = tree.getroot()
| classname = subelement.get("classname")
| encoding
| xml_declaration

## Variable Documentation

## ◆ classname

string parse-tests.classname = subelement.get("classname")

Definition at line 17 of file parse-tests.py.

## ◆ encoding

parse-tests.encoding

Definition at line 23 of file parse-tests.py.

## ◆ root

parse-tests.root = tree.getroot()

Definition at line 10 of file parse-tests.py.

## ◆ tree

parse-tests.tree = ET.parse("reports/nose2-junit.xml")

Definition at line 9 of file parse-tests.py.

## ◆ xml_declaration

parse-tests.xml_declaration

Definition at line 23 of file parse-tests.py.